var l=Object.defineProperty;var u=(a,e,r)=>e in a?l(a,e,{enumerable:!0,configurable:!0,writable:!0,value:r}):a[e]=r;var o=(a,e,r)=>u(a,typeof e!="symbol"?e+"":e,r);import{m as f,R as p,C as _,j as d}from"./index-DGn1DPCK.js";import{C as v}from"./camera-DJLV_IoI.js";var h=Object.defineProperty,S=Object.getOwnPropertyDescriptor,i=(a,e,r,s)=>{for(var t=s>1?void 0:s?S(e,r):e,c=a.length-1,m;c>=0;c--)(m=a[c])&&(t=(s?m(e,r,t):m(t))||t);return s&&t&&h(e,r,t),t};let n=class extends f(v){constructor(){super(...arguments);o(this,"cameraIframe");o(this,"cameraIFrameSource","")}startPlayback(){this.updateStatus("connecting");const r=this.buildAbsoluteUrl(this.camera.stream_url||"").toString();this.cameraIFrameSource=r,this.updateRawCameraUrl(r)}stopPlayback(){this.updateStatus("disconnected"),this.cameraIFrameSource="",this.cameraIframe.src=""}};i([p("streamingElement")],n.prototype,"cameraIframe",2);n=i([_({})],n);var C=function(){var e=this,r=e._self._c;return e._self._setupProxy,r("iframe",{ref:"streamingElement",staticStyle:{border:"none",width:"100%"},style:{"aspect-ratio":(e.camera.aspect_ratio||"16:9").replace(":","/"),...e.cameraStyle},attrs:{src:e.cameraIFrameSource},on:{load:function(s){return e.updateStatus("connected")},error:function(s){return e.updateStatus("error")}}})},I=[],b=d(n,C,I,!1,null,null);const g=b.exports;export{g as default};
